@@ -136,6 +136,19 @@ class UIHouseMapper(ObjectMapper):
         'postalCode': 'params__PostIndex__value',
     }
 
+
+class UISteadMapper(ObjectMapper):
+    """
+    Обертка над данными сервера m3-rest-gar о земельных участках.
+    Предназначена для использования в UI.
+    """
+
+    fields_map = {
+        'objectId': 'objectguid',
+        'steadNumber': 'number',
+        'postalCode': 'params__PostIndex__value',
+    }
+
 # -----------------------------------------------------------------------------
 # Загрузчики данных с сервера m3-rest-gar.
 
@@ -543,6 +556,42 @@ class HouseLoader(ParentFilterMixin, LoaderBase):
         return int(int_part) if int_part else -1, str_part
 
 
+class SteadLoader(ParentFilterMixin, LoaderBase):
+    """
+    Загрузчик сведений о земельных участках.
+    """
+
+    _default_hierarchy = GAR_HIERARCHY_MUN
+
+    @property
+    def _path(self):
+        return '/steads/'
+
+    @property
+    def _filter_param(self):
+        return 'number'
+
+    def _filter(self, object_data):
+        return True
+
+    def _sort_key(self, object_data):
+        return object_data['stead_number'] or ''
+
+    @staticmethod
+    def _split_number(number):
+        """Разделяет номер на целочисленную и буквенную части.
+
+        :param unicode number: Номер земельного участка.
+
+        :rtype: tuple
+        """
+
+        int_part = ''.join(ch for ch in number if ch.isdigit())
+        str_part = number[len(int_part):]
+
+        return int(int_part) if int_part else -1, str_part
+
+
 class UIHouseLoader(HouseLoader):
     _mapper_class = UIHouseMapper
 
@@ -596,6 +645,47 @@ class UIHouseLoader(HouseLoader):
 
         return house_data
 
+
+class UISteadLoader(SteadLoader):
+    _mapper_class = UISteadMapper
+
+    def _sort_key(self, object_data):
+        return tuple(chain(*(
+            self._split_number(object_data[number_type + 'Number'])
+            for number_type in ('stead',)
+        )))
+
+    def _filter(self, object_data):
+        """Возвращает True для записей, соответствующих параметрам поиска.
+
+        Запись считается соответствующей указанным при инициализации загрузчика
+        параметрам поиска, если:
+
+            * номер участка в записи **начинается со строки**,
+              указанной в аргументе ``filter_string``;
+            * в аргументе ``filter_string`` конструктора класса было передано
+              значение ``None``.
+
+        :rtype: bool
+        """
+
+        filter_string_lower = self.filter_string.lower()
+
+        if self.filter_string is None:
+            result = True
+        else:
+            stead = (object_data.get('steadNumber') or '').lower()
+            result = stead.startswith(filter_string_lower)
+
+        return result
+
+    def _process_object_data(self, drf_object_data):
+        stead_data = super(UISteadLoader, self)._process_object_data(drf_object_data)
+
+        stead_data['steadNumber'] = stead_data['steadNumber'] or ''
+
+        return stead_data
+
 # -----------------------------------------------------------------------------
 # Функции для создания объектов m3-gar-client на основе данных m3-rest-gar.
 
