@@ -132,6 +132,11 @@ Ext.m3.gar.AddressFields = Ext.extend(Ext.Component, {
         this.mon(this.zipCodeField, 'change', this.onZipChange, this);
     },
 
+    UserException: function(title, message) {
+        this.title = title;
+        this.message = message;
+    },
+
     initStreet: function() {
         this.mon(this.streetNameField, 'change', this.onStreetChange, this);
         this.mon(this.streetNameField, 'select', this.onStreetSelect, this);
@@ -667,7 +672,18 @@ Ext.m3.gar.AddressFields = Ext.extend(Ext.Component, {
 
         this.houseIDField.setValue(record.get('objectId'));
 
-        this.houseNumberField.setValue(record.get('houseNumber'));
+        if (record.get('houseNumber')) {
+            this.houseNumberField.setValue(record.get('houseNumber'))
+            this.flatNumberField.setReadOnly(false);
+            this.isSteadSelected = false;
+        } else if (record.get('steadNumber')) {
+            this.houseNumberField.setValue(record.get('steadNumber'));
+            this.flatNumberField.setReadOnly(true);
+            this.isSteadSelected = true;
+        }
+        else {
+            throw new this.UserException('Ошибка.', 'Не удалось получить номер дома или земельного участка.')
+        }
         this.buildingNumberField.setValue(record.get('buildingNumber'));
         this.structureNumberField.setValue(record.get('structureNumber'));
 
@@ -782,9 +798,16 @@ Ext.m3.gar.AddressFields = Ext.extend(Ext.Component, {
             }
             // значение дома может быть выбрано без указания улицы
             if (this.hasHouseField() && !this.isHouseEmpty()) {
-                addressParts.push(
-                    'д.' + this.houseNumberField.getValue()
-                );
+                if (this.isSteadSelected) {
+                    addressParts.push(
+                    'земельный участок ' + this.houseNumberField.getValue()
+                    );
+                }
+                else {
+                    addressParts.push(
+                   'д.' + this.houseNumberField.getValue()
+                    );
+                }
             }
 
             if (this.hasHouseField() && !this.isBuildingEmpty()) {
@@ -972,6 +995,9 @@ Ext.m3.gar.AddressViewBase = Ext.extend(Ext.Container, {
     houseTpl: [
         '<tpl for=".">',
             '<div class="x-combo-list-item">',
+                '<tpl if="steadNumber">',
+                    'уч.{steadNumber}',
+                '</tpl>',
                 '<tpl if="houseNumber">',
                     'д.{houseNumber}',
                 '</tpl>',
