@@ -41,9 +41,16 @@ Ext.override(Ext.m3.gar.AddressFields, {
             if (this.hasStreetField() && (!this.isStreetEmpty() ||
                   (this.isStreetEmpty() && this.streetNameField.allowBlank))) {
                 if (this.hasHouseField() && !this.isHouseEmpty()) {
-                    addressParts.push(
-                        'д.' + this.houseNumberField.getValue()
-                    );
+                    if (this.isSteadSelected) {
+                        addressParts.push(
+                        'земельный участок ' + this.houseNumberField.getValue()
+                        );
+                    }
+                    else {
+                        addressParts.push(
+                       'д.' + this.houseNumberField.getValue()
+                        );
+                    }
                 }
 
                 if (this.hasHouseField() && !this.isBuildingEmpty()) {
