@@ -54,6 +54,7 @@ class UIHouseMapper(ObjectMapper):
 
     fields_map = {
         'objectId': 'guid',
+        'steadNumber': 'number',
         'houseNumber': 'house_number',
         'buildingNumber': 'building_number',
         'structureNumber': 'structure_number',
@@ -284,6 +285,7 @@ class AddressFields(BaseExtComponent):
             read_only=self.read_only,
             fields=[
                 'objectId',
+                'steadNumber',
                 'houseNumber',
                 'buildingNumber',
                 'structureNumber',
@@ -461,6 +463,7 @@ class AddressFields(BaseExtComponent):
 
         put('level', self.level)
         put('garOnly', self.gar_only)
+        put('isSteadSelected', False)
 
         put('placeNameField', self.field__place_name.render)
         put('placeIDField', self.field__place_id.render)
